Enum Category
#[non_exhaustive]pub enum Category {
Error,
Session,
Transaction,
Span,
Attachment,
Monitor,
LogItem,
LogByte,
TraceMetric,
TraceMetricByte,
}Expand description
The category of data which was dropped.
Valid categories are listed in the develop docs; this enum may only define a subset of these valid data categories, but we will add further categories as we begin using them in the SDK.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Error
An error event.
Session
A session update or quantity of session outcomes contained in a session aggregate.
Transaction
A transaction event.
Dropped transactions should also be counted as dropped Spans: one for the
transaction root span extracted by Relay, plus one for each child span.
Span
A span.
When counting spans for a dropped transaction, the quantity includes all child spans plus one for the transaction root span extracted by Relay.
Attachment
A quantity of attachment bytes.
Monitor
A monitor check-in.
LogItem
A log item.
Dropped logs should also be counted as dropped LogBytes so client reports include
the approximate volume of dropped log data.
LogByte
A quantity of log bytes.
This complements LogItem: log_item counts dropped logs, while log_byte counts
their estimated byte size.
TraceMetric
A trace metric item.
Dropped trace metrics should also be counted as dropped TraceMetricBytes so client
reports include the approximate volume of dropped metric data.
TraceMetricByte
A quantity of trace metric bytes.
This complements TraceMetric: trace_metric counts dropped trace metrics, while
trace_metric_byte counts their estimated byte size.